==> haskell-warp-quic-0.0.0-262-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-KL1EdbaJK9E7PT2W2SfZRR
key:                  warp-quic-0.0.0-KL1EdbaJK9E7PT2W2SfZRR
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  989db8a84454118b0a9813c1a20fda60
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-KL1EdbaJK9E7PT2W2SfZRR
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    http3-0.0.2-7tO5fd1sK8x3FbKK8TIwqm
    quic-0.1.8-DkjtRPHSEFlCX3FdpfqyWx tls-1.9.0-BZn1846fJdJDaB7pkBb2yT
    wai-3.2.4-6cpnf6h7Rb79TjNKUlgvsl warp-3.3.30-EDiSg3yG2P12Zj8CUidnz6

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-quic-0.0.0-263-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-warp-quic.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp-quic
version:              0.0.0
visibility:           public
id:                   warp-quic-0.0.0-Dyl9TsSLJZ417xreIjDbN3
key:                  warp-quic-0.0.0-Dyl9TsSLJZ417xreIjDbN3
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/warp-quic
synopsis:             Warp based on QUIC
description:          WAI handler for HTTP/3 based on QUIC
category:             Network
abi:                  9cf74f7df72d5a118b25a71d8af926ff
exposed:              True
exposed-modules:      Network.Wai.Handler.WarpQUIC
import-dirs:          /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/warp-quic-0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp-quic
hs-libraries:         HSwarp-quic-0.0.0-Dyl9TsSLJZ417xreIjDbN3
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    http3-0.0.2-9eCsEsABnOs5K3QoOAQM1O
    quic-0.1.8-28YJ3FWfmUEAAHORjdXexW tls-1.9.0-FrcOA36lsSO6blwKEfqRMr
    wai-3.2.4-2yuuuf5uLwF7UpaG3b3aOb warp-3.3.30-BAuHIlDniWjE1q10IljmMm

haddock-interfaces:   /usr/share/doc/haskell-warp-quic/html/warp-quic.haddock
haddock-html:         /usr/share/doc/haskell-warp-quic/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
